<?php

namespace FiloBlu\LogView\Block\Adminhtml\Reports;

use Magento\Backend\Block\Widget\Grid\Extended;
use Magento\Backend\Block\Template\Context;
use Magento\Backend\Helper\Data;
use FiloBlu\LogView\Model\ResourceModel\Reports\Collection;

class Grid extends Extended {

    /**
     * @var Collection
     */
    protected $_collection;

    /**
     * Constructor
     *
     * @param Context $context
     * @param Data $backendHelper
     * @param Collection $collection
     * @param array $data
     */
    public function __construct(
    Context $context, Data $backendHelper, Collection $collection, array $data = []) {
        $this->_collection = $collection;
        parent::__construct($context, $backendHelper, $data);
    }

    /**
     * @return void
     * @noinspection MagicMethodsValidityInspection
     * @throws \Magento\Framework\Exception\FileSystemException
     */
    protected function _construct() {
        parent::_construct();
        $this->setId('reports_grid');
        $this->setDefaultSort('filename');
        $this->setDefaultDir('DESC');
    }

    protected function _prepareCollection() {

        $this->setCollection($this->_collection);
        return parent::_prepareCollection();
    }

    /**
     * @return \FiloBlu\LogView\Block\Adminhtml\Reports\Grid
     * @throws \Exception
     */
    protected function _prepareColumns() {
        $this->addColumn(
                'filename', [
            'header' => __('File Name'),
            'index' => 'filename',
            'sortable' => true,
            'filter' => false
                ]
        );
        
          $this->addColumn(
                'filesize', [
            'header' => __('File Size'),
            'index' => 'filesize',
            'sortable' => true,
            'filter' => false
                ]
        );

        return parent::_prepareColumns();
    }

    /**
     * Backend grid widget block
     *
     * @api
     * @deprecated 100.2.0 in favour of UI component implementation
     * @method string getRowClickCallback() getRowClickCallback()
     * @method \Magento\Backend\Block\Widget\Grid setRowClickCallback(string $value)
     * @SuppressWarnings(PHPMD.TooManyFields)
     * @since 100.0.2
     */
    public function getRowClickCallback() {
        return '
                function (grid, event) {
                    var trElement = Event.findElement(event, "tr");
                    
                    var fileName = trElement.down("td").innerHTML;
                   
                   var url = "' . $this->_backendHelper->getUrl(
                        'filoblulogviewadmin/reports/view', [
                        ]
                ) . 'file_name/" + fileName.replace(/^\s+|\s+$/g,"");
            window.open(url);
                }
            ';
    }

}
