<?php

/**
 * Copyright © 2015 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */

namespace FiloBlu\LogView\Controller\Adminhtml\Log;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\Controller\Result\JsonFactory;

/**
 *
 */
class ViewAjax extends Action
{

    public $log;
    protected $jsonResultFactory;
    protected $directory_list;
    private $maxSizeToLoad;
    /**
     * @var \Magento\Framework\Controller\Result\JsonFactory
     */
    private $resultJsonFactory;

    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory
     * @param \Magento\Framework\App\Filesystem\DirectoryList $directory_list
     * @throws \Magento\Framework\Exception\FileSystemException
     */
    public function __construct(
        Context $context,
        JsonFactory $resultJsonFactory,
        DirectoryList $directory_list
    ) {
        parent::__construct($context);
        $this->maxSizeToLoad = 2097152;
        $this->directory_list = $directory_list;
        $this->log = $this->directory_list->getPath('log') . DIRECTORY_SEPARATOR . $this->getRequest()->getParam(
                'file_name'
            );
        $this->resultJsonFactory = $resultJsonFactory;
    }

    /**
     * @return \Magento\Framework\Controller\ResultInterface|void
     */
    public function execute()
    {
        if ($this->getRequest()->isXmlHttpRequest()) {
            return $this->getNewLines(
                $this->getRequest()->getParam('lastsize'),
                $this->getRequest()->getParam('grep'),
                $this->getRequest()->getParam('invert')
            );
        }
    }

    /**
     * @param $lastFetchedSize
     * @param $grepKeyword
     * @param $invert
     * @return \Magento\Framework\Controller\Result\Json
     */
    public function getNewLines($lastFetchedSize, $grepKeyword, $invert)
    {
        $resultJson = $this->resultJsonFactory->create();

        /**
         * Clear the stat cache to get the latest results
         */
        clearstatcache();
        /**
         * Define how much we should load from the log file
         * @var
         */
        $fsize = filesize($this->log);
        $maxLength = ($fsize - $lastFetchedSize);

        /**
         * Verify that we don't load more data then allowed.
         */
        if ($maxLength > $this->maxSizeToLoad) {
            $resultJson->setData(
                [
                    'size' => $fsize,
                    'data' => [
                        'ERROR: PHPTail attempted to load more (' . round(
                            ($maxLength / 1048576),
                            2
                        ) . 'MB) then the maximum size (' . round(
                            ($this->maxSizeToLoad / 1048576),
                            2
                        ) . 'MB) of bytes into memory. You should lower the defaultUpdateTime to prevent this from happening. '
                    ]
                ]
            );
            return $resultJson;
        }
        /**
         * Actually load the data
         */
        $data = [];
        if ($maxLength > 0) {
            $fp = fopen($this->log, 'r');
            fseek($fp, -$maxLength, SEEK_END);
            $data = explode("\n", fread($fp, $maxLength));
        }
        /**
         * Run the grep function to return only the lines we're interested in.
         */
        if ($invert == 0) {
            $data = preg_grep("/$grepKeyword/", $data);
        } else {
            $data = preg_grep("/$grepKeyword/", $data, PREG_GREP_INVERT);
        }
        /**
         * If the last entry in the array is an empty string lets remove it.
         */
        if (end($data) == '') {
            array_pop($data);
        }
        $resultJson->setData(array('size' => $fsize, 'data' => $data));

        return $resultJson;
    }

    /**
     * Is the user allowed to view the store grid.
     *
     * @return bool
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('FiloBlu_LogView::general');
    }

}
