<?php

namespace FiloBlu\LogView\Model\ResourceModel\Log;

use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\Data\Collection as DataCollection;
use Magento\Framework\DataObject;

use function strlen;

class Collection extends DataCollection
{

    protected $directoryList;

    /**
     * @param \Magento\Framework\Data\Collection\EntityFactoryInterface $entityFactory
     * @param \Magento\Framework\App\Filesystem\DirectoryList $directory_list
     */
    public function __construct(
        DataCollection\EntityFactoryInterface $entityFactory,
        DirectoryList $directory_list
    ) {
        $this->directoryList = $directory_list;

        $this->populateGrid();

        parent::__construct($entityFactory);
    }

    protected function populateGrid()
    {
        foreach (glob($this->directoryList->getPath('log') . DIRECTORY_SEPARATOR . '*.log') as $file) {
            $obj = new DataObject();
            $this->addItem(
                $obj
                    ->setFilename(basename($file))
                    ->setPath($file)
                    ->setFilesize($this->human_filesize(filesize($file)))
            );
        }
    }

    /**
     * @param $bytes
     * @param $decimals
     * @return string
     */
    private function human_filesize($bytes, $decimals = 2)
    {
        $size = ['B', 'kB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];
        $factor = (int)floor((strlen($bytes) - 1) / 3);

        $factorLabel = $size[$factor] ?? '';
        return sprintf("%.{$decimals}f", $bytes / (1024 ** $factor)) . $factorLabel;
    }

    public function addFieldToFilter($field, $condition)
    {
    }

}
