<?php

namespace FiloBlu\LogView\Model\ResourceModel\Reports;

use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\Data\Collection as DataCollection;
use Magento\Framework\DataObject;

class Collection extends DataCollection
{

    protected $directory_list;

    public function __construct(
        DataCollection\EntityFactoryInterface $entityFactory,
        DirectoryList $directory_list
    ) {
        $this->directory_list = $directory_list;

        $this->populateGrid();

        parent::__construct($entityFactory);
    }

    protected function populateGrid()
    {
        foreach (
            glob(
                $this->directory_list->getPath('var') . DIRECTORY_SEPARATOR . 'report' . DIRECTORY_SEPARATOR . '*'
            ) as $file
        ) {
            $obj = new DataObject();
            $this->addItem(
                $obj
                    ->setFilename(basename($file))
                    ->setPath($file)
                    ->setFilesize($this->human_filesize(filesize($file)))
            );
        }
    }

    private function human_filesize($bytes, $decimals = 2)
    {
        $size = ['B', 'kB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];
        $factor = (int)floor((strlen($bytes) - 1) / 3);

        $factorLabel = $size[$factor] ?? '';
        return sprintf("%.{$decimals}f", $bytes / (1024 ** $factor)) . $factorLabel;
    }

    public function addFieldToFilter($field, $condition)
    {
    }

}
